@@ -4,6 +4,7 @@ from chzzk.exceptions.errors import (
     AuthenticationError,
     ChatConnectionError,
     ChatNotLiveError,
+    ChatReconnectError,
     ChzzkAPIError,
     ChzzkError,
     CookieAuthenticationError,
@@ -26,6 +27,7 @@ __all__ = [
     "AuthenticationError",
     "ChatConnectionError",
     "ChatNotLiveError",
+    "ChatReconnectError",
     "ChzzkAPIError",
     "ChzzkError",
     "CookieAuthenticationError",
